@@ -9,15 +9,16 @@ Number::Nary - encode and decode numbers as n-ary strings
 
 =head1 VERSION
 
-version 0.107
+version 0.108
 
 =cut
 
-our $VERSION = '0.107';
+our $VERSION = '0.108';
 
 use Carp qw(croak);
 use Scalar::Util qw(reftype);
 use List::MoreUtils qw(uniq);
+use UDCode ();
 
 use Sub::Exporter -setup => {
   exports => [ qw(n_codec n_encode n_decode) ],
@@ -145,15 +146,7 @@ sub _set_iterator {
 
   return _split_len_iterator($lengths[0]) if @lengths == 1;
 
-  for my $i (0 .. $#$digits) {
-    my $di = $digits->[$i];
-    for my $j (0 ..$#$digits) {
-      next if $i == $j;
-      my $dj = $digits->[$j];
-
-      croak "digit set may be ambiguous" if index($di, $dj) == 0;
-    }
-  }
+  croak "digit set may be ambiguous" if ! UDCode::is_udcode(@$digits);
 
   return _split_digit_iterator($digits);
 }
@@ -290,6 +283,12 @@ Mark Jason Dominus and Michael Peters offered some useful advice on how to weed
 out ambiguous digit sets, enabling me to allow digit sets made up of
 varying-length digits.
 
+=head1 SEE ALSO
+
+L<Math::BaseCalc> is in the same problem space wth Number::Nary.  It provides
+only an OO interface and does not reliably handle multicharacter digits or
+recognize ambiguous digit sets.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2005-2006 Ricardo Signes, all rights reserved.
